# **Dis-Utils**

- A very useful library for discord.py bots.

## Features

* Check topgg vote data
* Advance Paginator

```fix
More comming sool
```

# **Installation**

Install the stable version
```py
pip install dis-utils
```